@@ -42,7 +42,7 @@ create3D <- function(dcm, mode="double", transpose=TRUE, pixelData=TRUE,
       stop("DICOM \"img\" information is not present.")
     }
   } else {
-    if (is.null(dcm$hdr)) {
+    if (is.null(dcm$img)) {
       dcm <- list(hdr=dcm, img=NULL) # Only a list of headers as input
     }
   }
@@ -54,7 +54,8 @@ create3D <- function(dcm, mode="double", transpose=TRUE, pixelData=TRUE,
   if (length(Y) != 1) {
     stop("Column lengths are not identical.")
   }
-  Z <- length(dcm$hdr)
+  ## Check if the DICOM list has length > 1
+  Z <- ifelse(is.null(dim(dcm$img)), length(dcm$hdr), 1)
   img <- array(0, c(X,Y,Z))
   storage.mode(img) <- mode
   sliceLocation <- extractHeader(dcm$hdr, "SliceLocation")
@@ -75,15 +76,60 @@ create3D <- function(dcm, mode="double", transpose=TRUE, pixelData=TRUE,
   if (transpose) {
     img <- aperm(img, c(2,1,3))
   }
-  sliceLocation <<- sliceLocation[order(sliceLocation)]
   patientPosition <- unique(extractHeader(dcm$hdr, "PatientPosition", FALSE))
   if (length(patientPosition) != 1) {
     stop("PatientPosition(s) are not identical.")
   }
   if (patientPosition == "FFS") {
+    sliceLocation <- sliceLocation[order(sliceLocation)]
     img <- img[,,Z:1]
     sliceLocation <<- rev(sliceLocation)
+  } else {
+    sliceLocation <<- sliceLocation[order(sliceLocation)]
   }
   return(img)
 }
 
+create4D <- function(dcm, W, mode="double", transpose=TRUE,
+                     pixelData=TRUE, mosaic=FALSE, ...) {
+  if (pixelData) {
+    if (is.null(dcm$hdr)) {
+      stop("DICOM \"hdr\" information is not present.")
+    }
+    if (is.null(dcm$img)) {
+      stop("DICOM \"img\" information is not present.")
+    }
+  } else {
+    if (is.null(dcm$hdr)) {
+      dcm <- list(hdr=dcm, img=NULL) # Only a list of headers as input
+    }
+  }
+  X <- unique(extractHeader(dcm$hdr, "Rows"))
+  if (length(X) != 1) {
+    stop("Row lengths are not identical.")
+  }
+  Y <- unique(extractHeader(dcm$hdr, "Columns"))
+  if (length(Y) != 1) {
+    stop("Column lengths are not identical.")
+  }
+  Z <- length(dcm$hdr)
+  img <- array(0, c(X,Y,Z,W))
+  storage.mode(img) <- mode
+  sliceLocation <- extractHeader(dcm$hdr, "SliceLocation")
+  if (any(is.na(sliceLocation))) {
+    stop("Missing values are present in SliceLocation.")
+  }
+  if (pixelData) {
+    for (z in 1:Z) {
+      z.order <- order(sliceLocation)[z]
+      img[,,z] <- dcm$img[[z.order]]
+    }
+  } else {
+    for (z in 1:Z) {
+      z.order <- order(sliceLocation)[z]
+      img[,,z] <- dicomInfo(names(dcm$hdr)[z.order])$img
+    }
+  }
+
+  return(1)
+}
